**Example 1: 重新启动DSPA评估任务**



Input: 

```
tccli dsgc RestartDSPAAssessmentTask --cli-unfold-argument  \
    --DspaId dspa-92aabacd \
    --TaskId task-mdfmnme4
```

Output: 
```
{
    "Response": {
        "RequestId": "9a9f5c32-95ab-4130-ae37-047cde38b943"
    }
}
```

